@@ -5,13 +5,16 @@ source "$TOP/tests/common"
 source "$TOP/tests/common.convert"
 
 setup_root_helper
-prepare_test_dev 512M
+prepare_test_dev
 check_prereq btrfs-convert
+check_global_prereq mke2fs
+check_global_prereq lsattr
+check_global_prereq chattr
 
 fail=0
 default_mke2fs="mke2fs -t ext4 -b 4096"
 convert_test_preamble '' 'common inode flags test' 16k "$default_mke2fs"
-convert_test_prep_fs $default_mke2fs
+convert_test_prep_fs ext4 $default_mke2fs
 
 # create file with specific flags
 run_check $SUDO_HELPER touch "$TEST_MNT/flag_test"
@@ -31,4 +34,4 @@ if [ $? -ne 0 ]; then
 fi
 
 run_check_umount_test_dev
-convert_test_post_rollback
+convert_test_post_rollback ext4
