@@ -6,7 +6,7 @@ source $TOP/tests/common
 check_prereq btrfs-convert
 
 mkfs.ext4 -V &>/dev/null || _not_run "mkfs.ext4 not found"
-prepare_test_dev 1G
+prepare_test_dev
 
 for ((i = 0; i < 20; i++)); do
 	echo "loop $i" >>$RESULTS
